==> quantaxis-1.5.9-py3-none-any.whl: QUANTAXIS/QASelector/multilevel.py <==
# coding:utf-8
#
# The MIT License (MIT)
#
# Copyright (c) 2016-2019 yutiansut/QUANTAXIS
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from QUANTAXIS.QAUtil.QAParameter import FREQUENCE


class QA_MultiLevel(self):
    def __ini__(self, data):
        self.data = data
        self.level_data = {
            FREQUENCE.TICK: None,
            FREQUENCE.REALTIME_MIN: None
            FREQUENCE.REALTIME: None,
            FREQUENCE.ONE_MIN: None,
            FREQUENCE.FIVE_MIN: None,
            FREQUENCE.FIFTEEN_MIN: None,
            FREQUENCE.THIRTY_MIN: None,
            FREQUENCE.HOUR: None,
            FREQUENCE.DAY: None,
            FREQUENCE.WEEK: None,
            FREQUENCE.MONTH: None,
            FREQUENCE.YEAR: None
        }

    def resample(self):
        pass

==> quantaxis-1.6.6.dev1-py3-none-any.whl: QUANTAXIS/QASelector/multilevel.py <==
# coding:utf-8
#
# The MIT License (MIT)
#
# Copyright (c) 2016-2019 yutiansut/QUANTAXIS
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from QUANTAXIS.QAUtil.QAParameter import FREQUENCE


class QA_MultiLevel(self):
    def __ini__(self, data):
        self.data = data
        self.level_data = {
            FREQUENCE.TICK: None,
            FREQUENCE.REALTIME_MIN: None,
            FREQUENCE.REALTIME: None,
            FREQUENCE.ONE_MIN: None,
            FREQUENCE.FIVE_MIN: None,
            FREQUENCE.FIFTEEN_MIN: None,
            FREQUENCE.THIRTY_MIN: None,
            FREQUENCE.HOUR: None,
            FREQUENCE.DAY: None,
            FREQUENCE.WEEK: None,
            FREQUENCE.MONTH: None,
            FREQUENCE.YEAR: None
        }

    def resample(self):
        pass
